# Country
The country table is made by COKI, it contains country data, including each country's: ISO 3166 name, Wikipedia name,
ISO 3166 two letter alpha2 code, ISO 3166 three letter alpha3 code, United Nations Statistics Division M49 region name, 
United Nations Statistics Division M49 subregion name, Wikidata QID and Wikipedia URL.

## Latest schema
``` eval_rst
.. csv-table::
   :file: ../schemas/country_latest.csv
   :width: 100%
   :header-rows: 1
```